@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util;
 
-our $DATE = '2016-03-16'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2016-08-11'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -125,12 +125,21 @@ sub detect_perinci_cmdline_script {
             $reason = "Marked with # NO_PERINCI_CMDLINE_SCRIPT directive";
             last;
         }
-        if ($str =~ /^\s*(use|require)\s+
-                     (Perinci::CmdLine(|::Any|::Lite|::Classic))\b/mx) {
-            $yesno = 1;
-            $meta->{'func.module'} = $2;
-            last DETECT;
+
+        # NOTE: the presence of \s* pattern after ^ causes massive slowdown of
+        # the regex when we reach many thousands of lines, so we use split()
+
+        #if ($str =~ /^\s*(use|require)\s+
+        #    (Perinci::CmdLine(|::Any|::Lite|::Classic))/mx) {
+
+        for (split /^/, $str) {
+            if (/^\s*use\s+(Perinci::CmdLine(|::Any|::Lite|::Classic))\b/) {
+                $yesno = 1;
+                $meta->{'func.module'} = $2;
+                last DETECT;
+            }
         }
+
         if ($str =~ /^# PERICMD_INLINE_SCRIPT: (.+)/m) {
             $yesno = 1;
             $meta->{'func.module'} = 'Perinci::CmdLine::Inline';
@@ -192,7 +201,7 @@ Perinci::CmdLine::Util - Utility routines related to Perinci::CmdLine
 
 =head1 VERSION
 
-This document describes version 0.09 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2016-03-16.
+This document describes version 0.10 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2016-08-11.
 
 =head1 SYNOPSIS
 
